package MT::Plugin::SKR::CSVList;
########################################################################
#   CSVList - Apply templates by using values from CSV; Comma Separated Values
#           Copyright (c) 2007-2007 SKYARC System Co.,Ltd.
#           @see http://www.skyarc.co.jp/engineerblog/entry/3859.html
########################################################################
use strict;
use MT::Template::Context;
use MT::Util;

use vars qw( $MYNAME $VERSION );
$MYNAME = 'CSVList';
$VERSION = '1.00';

use constant MAX_COLUMNS => 20;

### Sub-Class
use base qw( MT::Plugin );
my $plugin = new MT::Plugin ({
        name => $MYNAME,
        version => $VERSION,
        author_name => q{ SKYARC System Co.,Ltd. },
        author_link => q{ http://www.skyarc.co.jp/ },
        doc_link => qw{ http://www.skyarc.co.jp/engineerblog/entry/3859.html },
        description => <<HTMLHEREDOC,
Build templates with stored comma separated values.
HTMLHEREDOC
});
MT->add_plugin( $plugin );

sub instance { $plugin }

### Retrieving the values (max to 20 columns)
foreach (1..MAX_COLUMNS) {
	MT::Template::Context->add_tag ("CSV$_" => \&_hdlr_csv);
}
sub _hdlr_csv {
    my ($ctx, $args) = @_;

    my $columns = $ctx->{__stash}->{__PACKAGE__. '::columns'}
        or return $ctx->error('not used in CSVList');
    my ($col_num) = $ctx->stash('tag') =~ m!.+(\d+)$!;

    $$columns[--$col_num];
}

### Container Tag
MT::Template::Context->add_container_tag (CSVList => \&_hdlr_csv_list);
sub _hdlr_csv_list {
    my ($ctx, $args, $cond) = @_;
    my $builder = $ctx->stash ('builder');
    my $tokens = $ctx->stash ('tokens');

    # Column delimitor
    my $delimitor = $args->{delimitor} || ',';

    # Compile data
    $args->{data}
        or return $ctx->error('<data> param must be specified');
    my $compiled = $builder->compile ($ctx, MT::Util::decode_html ($args->{data}))
        or return $ctx->error ('compile');
    my $data = $builder->build ($ctx, $compiled, $cond)
        or return $ctx->error ('build data');

    # Build template tags
    my $out = '';
    foreach my $row (split /[\r\n]/, $data) {
        $row =~ s!^\s+!!;
        $row =~ s!\s+$!!;
        next if $row eq '';# empty line
        next if $row =~ m!^[#|;]!;# comments
        my @columns = split $delimitor, $row;
        local $ctx->{__stash}->{__PACKAGE__. '::columns'} = \@columns;
        my $out2 = $builder->build ($ctx, $tokens, $cond)
            or return $ctx->error ('build');
        $out .= $out2;
    }

    $out;
}

1;
__END__
########################################################################
# '07/12/10 1.00    VKJ
